# -*- coding: utf-8 -*-
# Copyright 2012 Rackspace
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import os
import getpass
import logging

import keyring


class ServerHeraldLogger(object):
    def info(self, string):
        pass

    def warning(self, string):
        pass

    def error(self, string):
        pass

    def logger(self, enabled=True):
        if enabled:
            logger = logging.getLogger('serverherald')
            logger.setLevel(logging.INFO)
            log_file = os.path.expanduser('~/.serverherald/serverherald.log')
            fh = logging.FileHandler(log_file)
            fmt = ('%(asctime)s %(name)s[%(process)d] [%(levelname)s] '
                   '%(message)s')
            datefmt = '%b %d %H:%M:%S'
            formatter = logging.Formatter(fmt, datefmt)
            fh.setFormatter(formatter)
            logger.addHandler(fh)
            return logger
        else:
            return self


def config_has(config, section, key=None):
    if key:
        return key in config[section]
    return section in config


def config_get(config, section, key=None, default=None):
    """Return value that matches key in config settings.
    Reference keyring if needed.
    """
    config_section = config.get(section)
    if not key:
        return config_section
    if config_section.get(key, default) == 'USE_KEYRING':
        keyring_path = '%s/%s' % (section, key)
        keyring_value = keyring.get_password('serverherald', keyring_path)
        if keyring_value is None:
            print ('The keyring storage mechanism has been selected for'
                   '%s but the keyring is empty' % keyring_path)

            while 1:
                user_value = getpass.getpass("%s: " % key)
                if user_value != '':
                    keyring.set_password('serverherald', keyring_path,
                                         user_value)
                    break
            return user_value
        else:
            return keyring_value
    else:
        return config_section.get(key, default)



import sys
import requests

from serverherald.notifiers.base import ServerHeraldNotifyBase


class ServerHeraldNotifyTwilio(ServerHeraldNotifyBase):
    """Class for sending SMS notifications via Twilio API"""

    def validate_config(self):
        """Verify that all required config settings are present"""

        ServerHeraldNotifyBase.validate_config(self)

        # Twilio requires an Account SID, a token, a from, and a to phone
        # number
        if not self.config_has('twilio'):
            print ('`twilio` notification type requires a Twilio Account SID'
                   ', a token, a recipient and a sending phone number to be '
                   'specified in the config file.')
            sys.exit(1)

        required_fields = {
            'accountsid': 'Twilio requires an Account SID in the config file',
            'token': 'Twilio requires a token in the config file',
            'from': ('Twilio requires a sending phone number in the config '
                     'file'),
            'to': ('Twilio requires a recipient phone number in the config '
                   'file')}

        for field, message in required_fields.iteritems():
            if not self.config_has('twilio', field):
                print message
                sys.exit(1)

    def notify(self, context):
        """Send SMS notification"""
        url = ('https://api.twilio.com/2010-04-01/Accounts'
               '/%s/SMS/Messages.json' %
               self.config('twilio', 'accountsid'))
        data = {'From': self.config('twilio', 'from'),
                'To': self.config('twilio', 'to'),
                'Body': self.render_template('sms', context)}

        response = requests.post(url, data=data,
                                 auth=(self.config('twilio',
                                                   'accountsid'),
                                       self.config('twilio', 'token')))

        if response.status_code not in [200, 201]:
            print 'Twilio API Error: (%d) %s' % (response.status_code,
                                                 response.text)



import sys
import json
import requests

from serverherald.notifiers.base import ServerHeraldNotifyBase


class ServerHeraldNotifyWebhook(ServerHeraldNotifyBase):
    """Class for sending notifications as a HTTP(S) POST to a specified URL"""

    def validate_config(self):
        """Verify that all required config settings are present"""

        ServerHeraldNotifyBase.validate_config(self)

        # Webhook requires a URL
        if not self.config_has('webhook'):
            print ('`webhook` notification type requires a URL to be '
                   'specified in the config file.')
            sys.exit(1)

        if not self.config_has('webhook', 'url'):
            print 'Webhook requires a URL in the config file'
            sys.exit(1)

    def notify(self, context):
        """Send HTTP(S) notification"""
        url = self.config('webhook', 'url')
        response = requests.post(url,
                                 data=json.dumps(
                                     self.render_template('webhook',
                                                          context)))
        if response.status_code != 200:
            print 'Webhook Error: (%d) %s' % (response.status_code,
                                              response.text)



import sys
import requests

from serverherald.notifiers.base import ServerHeraldNotifyBase


class ServerHeraldNotifyNexmo(ServerHeraldNotifyBase):
    """Class for sending SMS notifications via Nexmo API"""

    def validate_config(self):
        """Verify that all required config settings are present"""
        ServerHeraldNotifyBase.validate_config(self)

        # Nexmo requires an API key, API secret, a from and a to phone
        # number
        if not self.config_has('nexmo'):
            print ('`nexmo` notification type requires a nexmo API key, API '
                   'secret, a recipient and a sending phone number to be '
                   'specified in the config file.')
            sys.exit(1)

        required_fields = {
            'apikey': 'nexmo requires an API key in the config file',
            'apisecret': 'nexmo requires an API secret in the config file',
            'from': ('nexmo requires a sending name or number in the config'
                     'file'),
            'to': 'nexmo requires a recipient phone number in the config file'}

        for field, message in required_fields.iteritems():
            if not self.config_has('nexmo', field):
                print message
                sys.exit(1)

    def notify(self, context):
        """Send SMS notification"""
        url = 'https://rest.nexmo.com/sms/json'
        data = {'api_key': self.config('nexmo', 'apikey'),
                'api_secret': self.config('nexmo', 'apisecret'),
                'from': self.config('nexmo', 'from'),
                'to': self.config('nexmo', 'to'),
                'text': self.render_template('sms', context)}

        response = requests.post(url, data=data)

        if response.status_code != 200:
            print 'nexmo API Error: (%d) %s' % (response.status_code,
                                                response.text)
        else:
            # Nexmo API returns 200 for application errors too"""
            for message in response.json()['messages']:
                if message['status'] != "0":
                    print 'nexmo API Error: %s' % message['error-text']



import sys
import requests

from serverherald.notifiers.base import ServerHeraldNotifyBase


class ServerHeraldNotifyPushover(ServerHeraldNotifyBase):
    """Class for sending push notifications via Pushover API"""

    def validate_config(self):
        """Verify that all required config settings are present"""

        ServerHeraldNotifyBase.validate_config(self)

        # Pushover requires an API key
        if not self.config_has('pushover'):
            print ('`pushover` notification type requires a Pushover API '
                   'key to be specified in the config file.')
            sys.exit(1)

        if not self.config_has('pushover', 'apikey'):
            print 'Pushover requires an API key in the config file'
            sys.exit(1)

    def notify(self, context):
        """Send message notification"""
        app_apikey = 'oPlGyPwBxgd5EicP1qocGV6bYi5RgF'
        url = 'https://api.pushover.net/1/messages.json'
        data = {'token': app_apikey,
                'user': self.config('pushover', 'apikey'),
                'message': self.render_template('sms', context)}
        response = requests.post(url, data=data)
        if response.status_code != 200:
            print 'Pushover API Error: (%d) %s' % (response.status_code,
                                                   response.text)



import sys
import json
import requests

from serverherald.notifiers.base import ServerHeraldNotifyBase


class ServerHeraldNotifyPagerduty(ServerHeraldNotifyBase):
    """Class for sending event notifications via PagerDuty API"""

    def validate_config(self):
        """Verify that all required config settings are present"""

        ServerHeraldNotifyBase.validate_config(self)

        # PagerDuty requires an API key
        if not self.config_has('pagerduty'):
            print ('`pagerduty` notification type requires a PagerDuty API '
                   'key to be specified in the config file.')
            sys.exit(1)

        if not self.config_has('pagerduty', 'apikey'):
            print 'PagerDuty requires an API key in the config file'
            sys.exit(1)

    def notify(self, context):
        """Send PagerDuty event"""
        url = ('https://events.pagerduty.com'
               '/generic/2010-04-15/create_event.json')
        description = 'Server %s online' % context['server'].name
        data = {'service_key': self.config('pagerduty', 'apikey'),
                'event_type': 'trigger',
                'description': description,
                'details': self.render_template('pagerduty', context)}

        response = requests.post(url, data=json.dumps(data))

        if response.status_code != 200:
            print 'PagerDuty API Error: (%d) %s' % (response.status_code,
                                                    response.text)



"""Server Herald methods for checking for new servers and sending
notifications using various services
"""

from serverherald.notifiers.smtp import ServerHeraldNotifySMTP
from serverherald.notifiers.mailgun import ServerHeraldNotifyMailgun
from serverherald.notifiers.sendgrid import ServerHeraldNotifySendgrid
from serverherald.notifiers.prowl import ServerHeraldNotifyProwl
from serverherald.notifiers.webhook import ServerHeraldNotifyWebhook
from serverherald.notifiers.pagerduty import ServerHeraldNotifyPagerduty
from serverherald.notifiers.twilio import ServerHeraldNotifyTwilio
from serverherald.notifiers.nexmo import ServerHeraldNotifyNexmo
from serverherald.notifiers.pushover import ServerHeraldNotifyPushover

__all__ = ['base', 'mail', 'mailgun', 'nexmo', 'pagerduty', 'prowl',
           'pushover', 'sendgrid', 'smtp', 'twilio', 'webhook']



import sys
import requests

from serverherald.notifiers.mail import ServerHeraldNotifyEmail


class ServerHeraldNotifyMailgun(ServerHeraldNotifyEmail):
    """Class for sending email notifications via Mailgun API"""

    def validate_config(self):
        """Verify that all required config settings are present"""

        ServerHeraldNotifyEmail.validate_config(self)

        # Mailgun requires a domain name and API key
        if not self.config_has('mailgun'):
            print ('`mailgun` notification type requires a Mailgun domain and'
                   ' API key to be specified in the config file.')
            sys.exit(1)

        if not self.config_has('mailgun', 'domain'):
            print 'Mailgun requires a domain name in the config file.'
            sys.exit(1)

        if not self.config_has('mailgun', 'apikey'):
            print 'Mailgun requires an API key in the config file'
            sys.exit(1)

    def notify(self, context):
        """Send email notification"""
        url = ('https://api.mailgun.net/v2/%s/messages' %
               self.config('mailgun', 'domain'))
        data = {'from': self.config('email', 'from'),
                'to': self.get_recipients(),
                'subject': self.get_subject(),
                'text': self.render_template('message', context)}
        response = requests.post(url, data=data,
                                 auth=('api', self.config('mailgun',
                                       'apikey')))
        if response.status_code != 200:
            print 'Mailgun API Error: (%d) %s' % (response.status_code,
                                                  response.text)



# -*- coding: utf-8 -*-
# Copyright 2012 Rackspace
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
serverherald announces when new Rackspace NextGen cloud server become ACTIVE.
"""
import os
import yaml
import sys
import argparse

import serverherald.notifiers
from serverherald import ServerHerald

""" Want a new notification type?
1. Make a new python file in notifiers/
2. Subclass ServerHeraldNotifyBase
3. Override notify() and validate_config() as needed.
4. Import it notifiers/__init__.py.
5. Add a new notification type keyword by appending to the notifiers dict in
   main()"""


def main():
    description = """serverherald announces when new Rackspace NextGen cloud
server become ACTIVE.
---------------------------------------------------------------------------"""

    parser = argparse.ArgumentParser(description=description)
    parser.add_argument('-s', '--silent', action='store_true', default=False,
                        help='Run silently, not sending any notification '
                             'emails. Useful for the initial run to build '
                             'a baseline of current servers')
    parser.add_argument('-c', '--config', type=str, default=None,
                        help='Configuration file path')

    args = parser.parse_args()

    # A user can specify a configuration file or we will go hunting for one
    config_file = args.config
    if config_file is None:
        possible_locations = ['serverherald.yaml', '~/.serverherald.yaml',
                              '~/.serverherald/serverherald.yaml',
                              '/etc/serverherald.yaml',
                              '/etc/serverherald/serverherald.yaml']
        for location in possible_locations:
            if os.path.exists(os.path.expanduser(location)):
                config_file = os.path.expanduser(location)
                break

        if config_file is None:
            print 'No configuration file found.'
            sys.exit(1)
    else:
        if not os.path.exists(os.path.expanduser(config_file)):
            print 'Configuration file %s does not exist.' % config_file
            sys.exit(1)

    with open(config_file, 'r') as f:
        config = yaml.load(f)

    if not 'method' in config:
        print '%s does not specify a notification method' % config_file
        sys.exit(1)

    # Dynamically determine the proper class for the notification method
    notifiers = {'smtp': 'ServerHeraldNotifySMTP',
                 'mailgun': 'ServerHeraldNotifyMailgun',
                 'sendgrid': 'ServerHeraldNotifySendgrid',
                 'prowl': 'ServerHeraldNotifyProwl',
                 'webhook': 'ServerHeraldNotifyWebhook',
                 'pagerduty': 'ServerHeraldNotifyPagerduty',
                 'twilio': 'ServerHeraldNotifyTwilio',
                 'nexmo': 'ServerHeraldNotifyNexmo',
                 'pushover': 'ServerHeraldNotifyPushover'}
    notifier = getattr(serverherald.notifiers,
                       notifiers[config['method']])

    herald = ServerHerald(config, notifier=notifier, silent=args.silent)
    try:
        herald.check_servers()
    except KeyboardInterrupt:
        print 'Stopping...'
        herald.logger.warning('Stopped by keyboard interrupt')
        herald.cleanup()

if __name__ == '__main__':
    main()



import os
import sys
from jinja2 import Environment, PackageLoader, FileSystemLoader

import serverherald.utils


class ServerHeraldNotifyBase(object):

    """Class for querying current cloud servers and sending
    notifications for new servers
    """

    def __init__(self, config):
        """Initialize the class by setting the path to the config file,
        checking file and directory locations and parsing the config file

        """

        self._config = config

        self.validate_config()
        self.template_env = Environment(loader=PackageLoader('serverherald',
                                        'templates'))

    def config(self, section, key=None, default=None):
        """Return the section or section/key value"""
        return serverherald.utils.config_get(self._config, section, key,
                                             default)

    def config_has(self, section, key=None):
        """Return true if the section/key pair exists"""
        return serverherald.utils.config_has(self._config, section, key)

    def validate_config(self):
        """Load the config.yaml file and validate it's contents within
        reason"""

        """
        if not self.config:
            print 'The config file is empty and must be populated'
            sys.exit(1)
        """

        accounts = self.config('accounts')
        if not accounts or not accounts.keys():
            print 'There are no accounts configured in the config file'
            sys.exit(1)

        for account, settings in accounts.iteritems():
            if 'apikey' not in settings:
                print 'Account %s does not have an API key' % account
                sys.exit(1)

    def render_template(self, templatename, context):
        """Render the template based on the data context.

        Users can override by creating ~/.serverherald/templates/templatename
        """
        template_dir = os.path.join(os.path.expanduser('~/.serverherald'),
                                    'templates')
        if os.path.isfile(os.path.join(template_dir, templatename)):
            template_env = Environment(loader=FileSystemLoader(template_dir))
            template = template_env.get_template(templatename)
            return template.render(context)
        else:
            template = self.template_env.get_template(templatename)
            return template.render(context)



import smtplib
from email.mime.text import MIMEText

from serverherald.notifiers.mail import ServerHeraldNotifyEmail


class ServerHeraldNotifySMTP(ServerHeraldNotifyEmail):
    """Class for sending email notifications via SMTP"""

    def notify(self, context):
        """Send email notification"""
        email = MIMEText(self.render_template('message', context))
        email['Subject'] = self.get_subject()
        email['From'] = self.config('email', 'from')
        email['To'] = ', '.join(self.get_recipients())
        sender = smtplib.SMTP()
        sender.connect()
        sender.sendmail(email['From'], self.get_recipients(),
                        email.as_string())
        sender.quit()



# -*- coding: utf-8 -*-
# Copyright 2012 Rackspace
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import os
import sys
import json
import getpass

import pyrax
import dateutil.parser

import serverherald.utils

"""
serverherald announces when new Rackspace NextGen cloud server become ACTIVE.
"""


class ServerHerald(object):

    """Class for querying current cloud servers and sending
    notifications for new servers
    """

    def __init__(self, config, notifier, silent=False):
        """Initialize the class by setting the path to the config file,
        checking file and directory locations and parsing the config file

        silent (boolean) specifies whether or not to send email notifications
        (optional)

        """

        self.silent = silent
        self._config = config
        self.notifier = notifier(config)

        self.check_files()

    def config(self, section, key=None, default=None):
        """Return the section or section/key value"""
        return serverherald.utils.config_get(self._config, section, key,
                                             default)

    def config_has(self, section, key=None):
        """Return true if the section/key pair exists"""
        return serverherald.utils.config_has(self._config, section, key)

    def check_files(self):
        """Check for the existence of the config.yaml file and validate that
        we can write to to the directory where the script lives for
        purposes of the cache file that will
        be created.
        """

        local_dir = os.path.expanduser('~/.serverherald')

        if not os.path.isdir(local_dir):
            if os.path.isfile(local_dir):
                print ('%s exists as a file, although it should be a '
                       'directory' % local_dir)
                sys.exit(1)
            try:
                os.makedirs(local_dir, 0700)
            except OSError:
                print 'Could not create the local directory %s' % local_dir
                sys.exit(1)

        test_file = '%s/writetest' % local_dir
        try:
            with open(test_file, 'w+') as f:
                f.write('test')
            os.unlink(test_file)
        except IOError:
            print ('It does not appear that the user (%s) this script was '
                   'executed as can write to\n%s' %
                   (getpass.getuser(), os.path.dirname(test_file)))
            sys.exit(1)

        logger = serverherald.utils.ServerHeraldLogger()
        self.logger = logger.logger(self.config('log'))

        self.lock_file = '%s/lock' % local_dir

        if os.path.isfile(self.lock_file):
            with open(self.lock_file) as f:
                lock_pid = f.read().strip()
            if os.path.isdir('/proc'):
                if os.path.isdir('/proc/%s' % lock_pid):
                    exe = os.readlink('/proc/%s/exe' % lock_pid)
                    if 'python' in exe:
                        print ('serverherald[%s] is currently running' %
                               lock_pid)
                        self.logger.warning('serverherald[%s] is currently '
                                            'running' % lock_pid)
                        sys.exit(1)
                    else:
                        print 'serverherald pid file found, but is not running'
                        self.logger.warning('serverherald pid file found, but '
                                            'is not running')
                        os.unlink(self.lock_file)
            else:
                print 'serverherald lockfile found'
                print 'serverherald cannot check the pid on this OS'
                self.logger.error('serverherald lockfile found')
                self.logger.error('serverherald cannot check the pid on this '
                                  'OS')
                sys.exit(1)

        with open(self.lock_file, 'w+') as f:
            f.write('%s' % os.getpid())

    def check_servers(self):
        """Check all regions for an Auth endpoint querying for all servers,
        sending notifications for new servers in ACTIVE status
        """

        self.logger.info('Starting to look for new servers')

        servers_file = os.path.expanduser('~/.serverherald/servers.json')
        if not os.path.isfile(servers_file):
            last_servers = {}
        else:
            with open(servers_file) as f:
                last_servers = json.load(f)
        servers = {}

        auth_file = os.path.expanduser('~/.serverherald/auth.json')
        if not os.path.isfile(auth_file):
            auth_details = {}
        else:
            with open(auth_file) as f:
                auth_details = json.load(f)

        new_servers = 0
        for username, settings in self.config('accounts').iteritems():
            self.logger.info('Username: %s' % username)

            endpoint = settings.get('endpoint', 'US')
            self.logger.info('Endpoint: %s' % endpoint)
            if endpoint == 'LON':
                pyrax.default_region = 'LON'

            if username in auth_details:
                user_auth_details = auth_details[username]
                pyrax.identity.username = username
                pyrax.identity.api_key = settings.get('apikey')
                pyrax.identity.token = user_auth_details.get('token')
                pyrax.identity.expires = dateutil.parser.parse(
                    user_auth_details.get('expires'))
                pyrax.identity.tenant_id = user_auth_details.get('tenant_id')
                pyrax.identity.tenant_name = (user_auth_details.
                                              get('tenant_name'))
                pyrax.identity.services = user_auth_details.get('services')
                pyrax.identity.user = user_auth_details.get('user')
                pyrax.identity.authenticated = True
            else:
                pyrax.set_credentials(username, settings.get('apikey'))
                if pyrax.identity.authenticated:
                    auth_details[username] = {
                        'token': pyrax.identity.token,
                        'expires': pyrax.identity.expires.isoformat(),
                        'tenant_id': pyrax.identity.tenant_id,
                        'tenant_name': pyrax.identity.tenant_name,
                        'services': pyrax.identity.services,
                        'user': pyrax.identity.user}
                    with open(auth_file, 'w+') as f:
                        json.dump(auth_details, f)

            if pyrax.identity.auth_endpoint == pyrax.identity.uk_auth_endpoint:
                regions = ['LON']
            else:
                regions = ['DFW', 'ORD']

            for region in regions:
                self.logger.info('Region: %s' % region)
                try:
                    cs = pyrax.connect_to_cloudservers(region)
                except:
                    continue
                flavors = cs.flavors.list()
                images = cs.images.list()
                for server in cs.servers.list():
                    id = server.id
                    status = server.status

                    if username not in servers:
                        servers[username] = []
                    if username not in last_servers:
                        last_servers[username] = []

                    servers[username].append(id)

                    if (status == 'ACTIVE'
                            and id not in last_servers[username]):
                        public_ips = server.addresses.get('public')
                        if public_ips:
                            ips = ', '.join([ver['addr'] for ver in
                                            public_ips])
                        else:
                            ips = 'None'
                        try:
                            image = filter(lambda x: x.id ==
                                           server.image['id'],
                                           images)[0].name
                        except IndexError:
                            image = cs.images.get(server.image['id']).name
                        flavor = filter(lambda x: int(x.id) == int(
                                        server.flavor['id']), flavors)[0].name

                        context = {'id': id, 'status': status,
                                   'server': server, 'server_image': image,
                                   'flavor': flavor, 'server_ips': ips,
                                   'server_ips_list': public_ips,
                                   'username': username, 'region': region}

                        self.logger.info('New Server: Hostname: (%s) IPs: (%s)'
                                         % (context['server'].name,
                                            context['server_ips']))
                        new_servers += 1
                        if not self.silent:
                            self.notifier.notify(context)

                if cs.client.auth_token != pyrax.identity.token:
                    pyrax.identity.token = cs.client.auth_token
                    auth_details[username]['token'] = cs.client.auth_token
                    with open(auth_file, 'w+') as f:
                        json.dump(auth_details, f)

        with open(servers_file, 'wb+') as f:
            json.dump(servers, f)

        os.unlink(self.lock_file)
        self.logger.info('Completed looking for new servers')
        self.logger.info('New servers found: %d' % new_servers)

    def cleanup(self):
        os.unlink(self.lock_file)



from setuptools import setup, find_packages

dependencies = ['hgtools', 'jinja2', 'keyring', 'pyrax', 'python-dateutil',
                'PyYAML', 'requests']

setup(
    name='serverherald',
    description=('serverherald announces when a new Rackspace OpenStack Cloud '
                 'Server becomes ACTIVE by polling the API. It supports '
                 'multiple notification methods, with email being the most '
                 'popular.'),
    keywords='rackspace cloud openstack serverherald',
    version='1.0.0',
    author='Matt Martz',
    author_email='matt.martz@rackspace.com',
    install_requires=dependencies,
    entry_points={'console_scripts':
                  ['serverherald=serverherald.shell:main']},
    packages=find_packages(exclude=['vagrant', 'tests', 'examples', 'doc']),
    package_data={
        'serverherald': ['templates/*'],
    },
    license='Apache License (2.0)',
    classifiers=["Programming Language :: Python"],
    url='https://github.com/rackerlabs/serverherald',
)



import sys
import requests

from serverherald.notifiers.base import ServerHeraldNotifyBase


class ServerHeraldNotifyProwl(ServerHeraldNotifyBase):
    """Class for sending push notifications via Prowl API"""

    def validate_config(self):
        """Verify that all required config settings are present"""

        ServerHeraldNotifyBase.validate_config(self)

        # Prowl requires an API key
        if not self.config_has('prowl'):
            print ('`prowl` notification type requires a Prowl API key to be '
                   'specified in the config file.')
            sys.exit(1)

        if not self.config_has('prowl', 'apikey'):
            print 'Prowl requires an API key in the config file'
            sys.exit(1)

    def notify(self, context):
        """Send message notification"""
        url = 'https://api.prowlapp.com/publicapi/add'

        data = {'apikey': self.config('prowl', 'apikey'),
                'priority': self.config('prowl', 'priority', 0),
                'application': 'Server Herald',
                'event': 'New Server',
                'description': self.render_template('prowl', context)}

        response = requests.post(url, data=data)
        if response.status_code != 200:
            print 'Prowl API Error: (%d) %s' % (response.status_code,
                                                response.text)



import sys
from serverherald.notifiers.base import ServerHeraldNotifyBase


class ServerHeraldNotifyEmail(ServerHeraldNotifyBase):
    """Parent class for sending email notifications.
    This doesn't supply notify() and should not be used directly.
    """

    def validate_config(self):
        """Email notifications require a `to` and `from` address"""
        ServerHeraldNotifyBase.validate_config(self)

        if not self.config_has('email') or not self.config_has('email', 'to'):
            print 'There are no recipient email addresses in the config file'
            sys.exit(1)

        if not self.config_has('email', 'from'):
            print 'A from address has not been specified in the config file'
            sys.exit(1)

    def get_subject(self):
        """Set the email subject based on config, fall back to default"""
        return self.config('email', 'subject', 'New Cloud Server Online')

    def get_recipients(self):
        """Convert recipients from the config file into a list, if needed"""
        recipients = self.config('email', 'to')
        if not isinstance(recipients, list):
            recipients = [recipients]
        return recipients



import sys
import requests

from serverherald.notifiers.mail import ServerHeraldNotifyEmail


class ServerHeraldNotifySendgrid(ServerHeraldNotifyEmail):
    """Class for sending email notifications via Sendgrid API"""

    def validate_config(self):
        """Verify that all required config settings are present"""

        ServerHeraldNotifyEmail.validate_config(self)

        # Sendgrid requires an API key and API username
        if not self.config_has('sendgrid'):
            print ('`sendgrid` notification type requires an API username'
                   ' and an API key to be specified in the config file.')
            sys.exit(1)

        if not self.config_has('sendgrid', 'apiuser'):
            print 'Sendgrid requires a domain name in the config file.'
            sys.exit(1)

        if not self.config_has('sendgrid', 'apikey'):
            print 'Sendgrid requires an API key in the config file'
            sys.exit(1)

    def notify(self, context):
        """Send email notification"""
        url = 'https://sendgrid.com/api/mail.send.json'
        data = {'api_user': self.config('sendgrid', 'apiuser'),
                'api_key': self.config('sendgrid', 'apikey'),
                'to': self.get_recipients(),
                'from': self.config('email', 'from'),
                'subject': self.get_subject(),
                'text': self.render_template('message', context)}

        response = requests.post(url, data=data)

        if response.status_code != 200:
            print 'Sendgrid API Error: (%d) %s' % (response.status_code,
                                                   response.text)
